@@ -191,11 +191,11 @@ void SearchManager::checkRoot()
     LinkChecker* checker = new LinkChecker(&root_, time_out_, this, "link_checker");
     checker->setSearchManager(this);
 
-    connect(checker, TQT_SIGNAL(transactionFinished(const LinkStatus *, LinkChecker *)),
-            this, TQT_SLOT(slotRootChecked(const LinkStatus *, LinkChecker *)));
+    connect(checker, TQ_SIGNAL(transactionFinished(const LinkStatus *, LinkChecker *)),
+            this, TQ_SLOT(slotRootChecked(const LinkStatus *, LinkChecker *)));
     /*
-        connect(checker, TQT_SIGNAL(jobFinnished(LinkChecker *)),
-                this, TQT_SLOT(slotLinkCheckerFinnished(LinkChecker *)));
+        connect(checker, TQ_SIGNAL(jobFinnished(LinkChecker *)),
+                this, TQ_SLOT(slotLinkCheckerFinnished(LinkChecker *)));
     */
     checker->check();
 }
@@ -524,11 +524,11 @@ void SearchManager::checkLinksSimultaneously(vector<LinkStatus*> const& links)
             LinkChecker* checker = new LinkChecker(ls, time_out_, this, "link_checker");
             checker->setSearchManager(this);
 
-            connect(checker, TQT_SIGNAL(transactionFinished(const LinkStatus *, LinkChecker *)),
-                    this, TQT_SLOT(slotLinkChecked(const LinkStatus *, LinkChecker *)));
+            connect(checker, TQ_SIGNAL(transactionFinished(const LinkStatus *, LinkChecker *)),
+                    this, TQ_SLOT(slotLinkChecked(const LinkStatus *, LinkChecker *)));
             /*
-                        connect(checker, TQT_SIGNAL(jobFinnished(LinkChecker *)),
-                                this, TQT_SLOT(slotLinkCheckerFinnished(LinkChecker *)));
+                        connect(checker, TQ_SIGNAL(jobFinnished(LinkChecker *)),
+                                this, TQ_SLOT(slotLinkCheckerFinnished(LinkChecker *)));
             */
             checker->check();
         }
