@@ -40,7 +40,7 @@ class TDEToggleAction;
  */
 class KLinkStatus : public KParts::MainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KLinkStatus();
