@@ -44,17 +44,17 @@ ActionEditor::ActionEditor( TQWidget* parent,  const char* name, WFlags fl )
     buttonConnect->setEnabled( false );
 
     TQPopupMenu *popup = new TQPopupMenu( this );
-    popup->insertItem( i18n("New &Action" ), this, TQT_SLOT( newAction() ) );
-    popup->insertItem( i18n("New Action &Group" ), this, TQT_SLOT( newActionGroup() ) );
-    popup->insertItem( i18n("New &Dropdown Action Group" ), this, TQT_SLOT( newDropDownActionGroup() ) );
+    popup->insertItem( i18n("New &Action" ), this, TQ_SLOT( newAction() ) );
+    popup->insertItem( i18n("New Action &Group" ), this, TQ_SLOT( newActionGroup() ) );
+    popup->insertItem( i18n("New &Dropdown Action Group" ), this, TQ_SLOT( newDropDownActionGroup() ) );
     buttonNewAction->setPopup( popup );
     buttonNewAction->setPopupDelay( 0 );
 
-    connect( listActions, TQT_SIGNAL( insertAction() ), this, TQT_SLOT( newAction() ) );
-    connect( listActions, TQT_SIGNAL( insertActionGroup() ), this, TQT_SLOT( newActionGroup() ) );
-    connect( listActions, TQT_SIGNAL( insertDropDownActionGroup() ), this, TQT_SLOT( newDropDownActionGroup() ) );
-    connect( listActions, TQT_SIGNAL( deleteAction() ), this, TQT_SLOT( deleteAction() ) );
-    connect( listActions, TQT_SIGNAL( connectAction() ), this, TQT_SLOT( connectionsClicked() ) );
+    connect( listActions, TQ_SIGNAL( insertAction() ), this, TQ_SLOT( newAction() ) );
+    connect( listActions, TQ_SIGNAL( insertActionGroup() ), this, TQ_SLOT( newActionGroup() ) );
+    connect( listActions, TQ_SIGNAL( insertDropDownActionGroup() ), this, TQ_SLOT( newDropDownActionGroup() ) );
+    connect( listActions, TQ_SIGNAL( deleteAction() ), this, TQ_SLOT( deleteAction() ) );
+    connect( listActions, TQ_SIGNAL( connectAction() ), this, TQ_SLOT( connectionsClicked() ) );
 }
 
 void ActionEditor::closeEvent( TQCloseEvent *e )
@@ -86,10 +86,10 @@ void ActionEditor::deleteAction()
 	    formWindow->actionList().removeRef( currentAction );
 	    delete currentAction;
 	    TQValueList<MetaDataBase::Connection> conns =
-		MetaDataBase::connections( TQT_TQOBJECT(formWindow), currentAction );
+		MetaDataBase::connections( formWindow, currentAction );
 	    for ( TQValueList<MetaDataBase::Connection>::Iterator it2 = conns.begin();
 		  it2 != conns.end(); ++it2 )
-		MetaDataBase::removeConnection( TQT_TQOBJECT(formWindow), (*it2).sender, (*it2).signal,
+		MetaDataBase::removeConnection( formWindow, (*it2).sender, (*it2).signal,
 						(*it2).receiver, (*it2).slot );
 	    delete it.current();
 	    break;
@@ -97,10 +97,10 @@ void ActionEditor::deleteAction()
 	    formWindow->actionList().removeRef( currentAction );
 	    delete currentAction;
 	    TQValueList<MetaDataBase::Connection> conns =
-		MetaDataBase::connections( TQT_TQOBJECT(formWindow), currentAction );
+		MetaDataBase::connections( formWindow, currentAction );
 	    for ( TQValueList<MetaDataBase::Connection>::Iterator it2 = conns.begin();
 		  it2 != conns.end(); ++it2 )
-		MetaDataBase::removeConnection( TQT_TQOBJECT(formWindow), (*it2).sender, (*it2).signal,
+		MetaDataBase::removeConnection( formWindow, (*it2).sender, (*it2).signal,
 						(*it2).receiver, (*it2).slot );
 	    delete it.current();
 	    break;
@@ -109,7 +109,7 @@ void ActionEditor::deleteAction()
     }
 
     if ( formWindow )
-	formWindow->setActiveObject( TQT_TQOBJECT(formWindow->mainContainer()) );
+	formWindow->setActiveObject( formWindow->mainContainer() );
 }
 
 void ActionEditor::newAction()
@@ -257,7 +257,7 @@ void ActionEditor::updateActionIcon( TQAction *a )
 
 void ActionEditor::connectionsClicked()
 {
-    ConnectionEditor editor( formWindow->mainWindow(), TQT_TQOBJECT(currentAction), TQT_TQOBJECT(formWindow), formWindow );
+    ConnectionEditor editor( formWindow->mainWindow(), currentAction, formWindow, formWindow );
     editor.exec();
 }
 #include "actioneditorimpl.moc"
