@@ -27,7 +27,7 @@
 
 class TimeStamp : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
