@@ -9,6 +9,11 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "kmdrmainwindow.h"
 
 #include <tqtimer.h>
@@ -16,7 +21,7 @@
 KmdrMainWindow::KmdrMainWindow(TQWidget *parent, const char *name, WFlags f)
  : TDEMainWindow(parent, name, f)
 {
-  TQTimer::singleShot(10, this, TQT_SIGNAL(initialize()));
+  TQTimer::singleShot(10, this, TQ_SIGNAL(initialize()));
 }
 
 
