@@ -1220,12 +1220,6 @@ xsldbgInit()
         xsltSetGenericErrorFunc(0, xsldbgGenericErrorFunc);
 #endif
 
-	/*
-	 * disable CDATA from being built in the document tree
-	 */
-	xmlDefaultSAXHandlerInit();
-	xmlDefaultSAXHandler.cdataBlock = NULL;
-
         if (getThreadStatus() != XSLDBG_MSG_THREAD_NOTUSED) {
             initialized = 1;
             return 1;           /* this is all we need to do when running as a thread */
