@@ -59,10 +59,10 @@ QuantaDebuggerDBGp::QuantaDebuggerDBGp (TQObject *parent, const char*, const TQS
   setExecutionState(m_defaultExecutionState);
   emit updateStatus(DebuggerUI::NoSession);
   
-  connect(&m_network, TQT_SIGNAL(command(const TQString&)), this, TQT_SLOT(processCommand(const TQString&)));
-  connect(&m_network, TQT_SIGNAL(active(bool)), this, TQT_SLOT(slotNetworkActive(bool)));
-  connect(&m_network, TQT_SIGNAL(connected(bool)), this, TQT_SLOT(slotNetworkConnected(bool)));
-  connect(&m_network, TQT_SIGNAL(networkError(const TQString &, bool)), this, TQT_SLOT(slotNetworkError(const TQString &, bool)));
+  connect(&m_network, TQ_SIGNAL(command(const TQString&)), this, TQ_SLOT(processCommand(const TQString&)));
+  connect(&m_network, TQ_SIGNAL(active(bool)), this, TQ_SLOT(slotNetworkActive(bool)));
+  connect(&m_network, TQ_SIGNAL(connected(bool)), this, TQ_SLOT(slotNetworkConnected(bool)));
+  connect(&m_network, TQ_SIGNAL(networkError(const TQString &, bool)), this, TQ_SLOT(slotNetworkError(const TQString &, bool)));
 
 }
 
