@@ -111,7 +111,7 @@ struct ToolbarEntry;
   */
 class QuantaApp : public KMdiMainFrm, public DCOPWindowManagerIf
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 friend class QuantaInit;
